@@ -1,7 +1,6 @@
 def main():
 
     import pandas as pd
-    pd.set_option('display.max_columns', None)
     from o2o import BivariateHawkesProcessSimulator, ParameterEstimator, O2OAnalyzer
 
     M = int(input('Give the number of users:   '))
@@ -17,7 +16,7 @@ def main():
     # Fit model
     print('Data generated!! Fitting started... This may take sometime \n')
     estimator = ParameterEstimator(data_online, data_offline, M, T)
-    fit = estimator.fit_model(data_online, data_offline, M, T)
+    fit = estimator.fit_model()
 
 
     #Print estimation results
